@@ -534,7 +534,7 @@ def seed(complexity, p):
     )
 
 
-def expand(f, single_account, subset):
+def expand(f, single_account, subset=None):
     click.echo("Expanding")
     puppet_account_id = config.get_puppet_account_id()
     manifest = manifest_utils.load(f, puppet_account_id)
